==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/ru.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Вы не можете удалить свои собственные права на чтение.",
    "Team folders" : "Командные папки",
    "Admin configured folders shared with everyone in a team" : "Папки, настроенные администратором, являются общими для всех членов команды",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки.\n\nНачиная с Hub 10/Nextcloud 31, администратор должен быть участником команды, чтобы иметь возможность назначить Командную папку.",
    "Unset" : "Снять",
    "Denied (Inherited permission)" : "Запрещено (унаследовано)",
    "Allowed (Inherited permission)" : "Разрешено (унаследовано)",
    "Denied" : "Запрещено",
    "Allowed" : "Разрешено",
    "Access denied" : "Доступ запрещён",
    "Access allowed" : "Доступ разрешен",
    "Inherit permission" : "Наследование разрешений",
    "Deny" : "Запретить",
    "Allow" : "Разрешить",
    "Group" : "Группа",
    "Team" : "Команда",
    "Team folder" : "Командная папка",
    "Read" : "Чтение",
    "Write" : "Запись",
    "Create" : "Создать",
    "Delete" : "Удалить",
    "Share" : "Публикация",
    "You" : "Вы",
    "Remove access rule" : "Удалить правило доступа",
    "Add advanced permission rule" : "Добавить расширенное правило доступа",
    "Select a user or group" : "Выберите пользователя или группу",
    "Open Team folder" : "Открыть Командную папку",
    "Permission denied. User does not have sufficient permissions." : "В доступе отказано. У пользователя недостаточно прав.",
    "Unexpected status from server" : "Неожиданный статус от сервера",
    "List of Team folders." : "Список Командных папок.",
    "No Team folders yet" : "Пока нет Командных папок",
    "Team folders will show up here" : "Здесь будут отображаться Командные папки",
    "Add group" : "Добавить группу",
    "Default" : "По умолчанию",
    "Unlimited" : "Неограничено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Действительно удалить {folderName} и все вложенные файлы? Эта операция необратима.",
    "Delete \"{folderName}\"?" : "Удалить «{folderName}\"»?",
    "Team folder admin delegation" : "Делегирование полномочий администратора Командной папки",
    "They will have access to all Team folders." : "Они будут иметь доступ ко всем Командным папкам.",
    "They will only have access to Team folders for which they have advanced permissions." : "Они будут иметь доступ только к тем Командным папкам, для которых у них есть расширенные права.",
    "Group or team" : "Группа или команда",
    "Sort by number of groups or teams that have access to this folder" : "Сортировка по количеству групп или команд, имеющих доступ к этой папке",
    "Sort by number of groups that have access to this folder" : "Сортировать по количеству групп, имеющих доступ к этой папке",
    "Folder name" : "Имя папки",
    "Quota" : "Квота",
    "Advanced Permissions" : "Расширенные права доступа",
    "Pagination of team folders" : "Пагинация папок команды",
    "Previous" : "Назад",
    "Next" : "Далее",
    "User" : "Пользователь",
    "Unknown" : "Неизвестно",
    "Users/groups that can manage" : "Пользователи/группы, которые могут управлять",
    "None" : "Отсутствует",
    "No other groups or teams available" : "Других доступных групп или команд нет",
    "No other groups available" : "Других доступных групп нет",
    "{displayName} (team)" : "{displayName} (команда)",
    "Add group or team" : "Добавить группу или команду",
    "{size} used" : "использовано {size}",
    "Other …" : "Прочее...",
    "You can not remove your own read permission." : "Вы не можете удалить свои собственные права на чтение.",
    "Group folders" : "Папки групп",
    "Admin configured folders shared with everyone in a group" : "Папки, настроенные администратором, являются общими для всех членов группы",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам группы.\n\nПапки можно настроить в разделе *Групповые папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким группам, управлять их правами на запись и совместное использование, а также задать квоту для папки.",
    "Group folder" : "Групповая папка",
    "Open group folder" : "Открыть Групповую папку",
    "List of group folders." : "Список Групповых папок.",
    "No group folders yet" : "Пока нет Групповых папок",
    "Group folders will show up here" : "Здесь будут отображаться Групповые папки",
    "Group folder admin delegation" : "Делегирование полномочий администратора Групповой папки",
    "They will have access to all group folders." : "Они будут иметь доступ ко всем Групповым папкам.",
    "They will only have access to group folders for which they have advanced permissions." : "Они будут иметь доступ только к тем Групповым папкам, для которых у них есть расширенные права.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/ru.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Вы не можете удалить свои собственные права на чтение.",
    "Team folders" : "Командные папки",
    "Unset" : "Снять",
    "Denied (Inherited permission)" : "Запрещено (унаследовано)",
    "Allowed (Inherited permission)" : "Разрешено (унаследовано)",
    "Denied" : "Запрещено",
    "Allowed" : "Разрешено",
    "Access denied" : "Доступ запрещён",
    "Access allowed" : "Доступ разрешен",
    "Inherit permission" : "Наследование разрешений",
    "Deny" : "Запретить",
    "Allow" : "Разрешить",
    "Group" : "Группа",
    "Team" : "Команда",
    "Team folder" : "Командная папка",
    "Read" : "Чтение",
    "Write" : "Запись",
    "Create" : "Создать",
    "Delete" : "Удалить",
    "Share" : "Публикация",
    "You" : "Вы",
    "Remove access rule" : "Удалить правило доступа",
    "Add advanced permission rule" : "Добавить расширенное правило доступа",
    "Select a user or group" : "Выберите пользователя или группу",
    "Open Team folder" : "Открыть Командную папку",
    "Permission denied. User does not have sufficient permissions." : "В доступе отказано. У пользователя недостаточно прав.",
    "Unexpected status from server" : "Неожиданный статус от сервера",
    "List of Team folders." : "Список Командных папок.",
    "No Team folders yet" : "Пока нет Командных папок",
    "Team folders will show up here" : "Здесь будут отображаться Командные папки",
    "Add group" : "Добавить группу",
    "Default" : "По умолчанию",
    "Unlimited" : "Неограничено",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Действительно удалить {folderName} и все вложенные файлы? Эта операция необратима.",
    "Delete \"{folderName}\"?" : "Удалить «{folderName}\"»?",
    "Team folder admin delegation" : "Делегирование полномочий администратора Командной папки",
    "They will have access to all Team folders." : "Они будут иметь доступ ко всем Командным папкам.",
    "They will only have access to Team folders for which they have advanced permissions." : "Они будут иметь доступ только к тем Командным папкам, для которых у них есть расширенные права.",
    "Group or team" : "Группа или команда",
    "Sort by number of groups or teams that have access to this folder" : "Сортировка по количеству групп или команд, имеющих доступ к этой папке",
    "Sort by number of groups that have access to this folder" : "Сортировать по количеству групп, имеющих доступ к этой папке",
    "Folder name" : "Имя папки",
    "Quota" : "Квота",
    "Advanced Permissions" : "Расширенные права доступа",
    "Pagination of team folders" : "Пагинация папок команды",
    "Previous" : "Назад",
    "Next" : "Далее",
    "User" : "Пользователь",
    "Unknown" : "Неизвестно",
    "Users/groups that can manage" : "Пользователи/группы, которые могут управлять",
    "None" : "Отсутствует",
    "No other groups or teams available" : "Других доступных групп или команд нет",
    "No other groups available" : "Других доступных групп нет",
    "{displayName} (team)" : "{displayName} (команда)",
    "Add group or team" : "Добавить группу или команду",
    "{size} used" : "использовано {size}",
    "Other …" : "Прочее...",
    "You can not remove your own read permission." : "Вы не можете удалить свои собственные права на чтение.",
    "Group folders" : "Папки групп",
    "Admin configured folders shared with everyone in a group" : "Папки, настроенные администратором, являются общими для всех членов группы",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам группы.\n\nПапки можно настроить в разделе *Групповые папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким группам, управлять их правами на запись и совместное использование, а также задать квоту для папки.",
    "Group folder" : "Групповая папка",
    "Open group folder" : "Открыть Групповую папку",
    "List of group folders." : "Список Групповых папок.",
    "No group folders yet" : "Пока нет Групповых папок",
    "Group folders will show up here" : "Здесь будут отображаться Групповые папки",
    "Group folder admin delegation" : "Делегирование полномочий администратора Групповой папки",
    "They will have access to all group folders." : "Они будут иметь доступ ко всем Групповым папкам.",
    "They will only have access to group folders for which they have advanced permissions." : "Они будут иметь доступ только к тем Групповым папкам, для которых у них есть расширенные права.",
    "Admin configured folders shared with everyone in a team" : "Папки, настроенные администратором, являются общими для всех членов команды",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки.\n\nНачиная с Hub 10/Nextcloud 31, администратор должен быть участником команды, чтобы иметь возможность назначить Командную папку."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
